@@ -1,5 +1,4 @@
 from skilletlib import Panoply
-from skilletlib.exceptions import PanoplyException
 
 from .base import BaseCommand
 from ..decorators import require_ngfw_connection_params
@@ -14,11 +13,6 @@ class CommitCommand(BaseCommand):
     @require_ngfw_connection_params
     @require_panoply_connection
     def run(self, pan: Panoply):
-        try:
-            print("Committing configuration...")
-            pan.commit()
-            print("Success...")
-
-        except PanoplyException as pe:
-            print(pe)
-            exit(1)
+        print("Committing configuration...")
+        pan.commit()
+        print("Success...")
